# Installation

For a fresh install:
```shell
git clone git@github.com:daniel-koudouna/conceptual.git
cd conceptual
pip install .
```

For developing:
```
python setup.py bdist_wheel
python -m pip install dist/*
```
